==> ark-20.11.90.tar.xz: ark-20.11.90/plugins/libsinglefileplugin/kerfuffle_libxz.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the lzma algorithm",
        "Description[az]": "lzma alqoritmi ilə sıxlaşdırılan tək faylları açmaq və çıxartmaq",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «lzma»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «lzma»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem lzma",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med lzma-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem LZMA-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο Izma",
        "Description[en_GB]": "Open and extract single files compressed with the lzma algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo lzma",
        "Description[et]": "Lzma algoritmiga pakitud failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi lzma algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[fi]": "Avaa ja pura LZMA-algoritmilla pakattuja yksittäistiedostoja",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme lzma",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo lzma.",
        "Description[hu]": "Az lzma algoritmussal tömörített fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo lzma",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo lzma",
        "Description[ko]": "lzma 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het lzma-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med lzma-algoritmen",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem lzma",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo LZMA",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo LZMA",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul lzma",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму lzma",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom lzma",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom lzma",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом ЛЗМА",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom LZMA",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom LZMA",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом ЛЗМА",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med lzma-algoritmen",
        "Description[tr]": "Lzma algoritması ile sıkıştırılmış tek dosyaları açma ve çıkarma",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму lzma",
        "Description[x-test]": "xxOpen and extract single files compressed with the lzma algorithmxx",
        "Description[zh_CN]": "打开和解压 lzma 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 lzma 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libxz",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "LZMA plugin",
        "Name[az]": "LZMA qoşması",
        "Name[ca@valencia]": "Connector del LZMA",
        "Name[ca]": "Connector del LZMA",
        "Name[cs]": "Modul pro LZMA",
        "Name[da]": "LZMA-plugin",
        "Name[de]": "LZMA-Modul",
        "Name[el]": "Πρόσθετο LZMA",
        "Name[en_GB]": "LZMA plugin",
        "Name[es]": "Complemento LZMA",
        "Name[et]": "LZMA plugin",
        "Name[eu]": "LZMA plugina",
        "Name[fi]": "LZMA-liitännäinen",
        "Name[fr]": "Module externe LZMA",
        "Name[gl]": "Complemento de LZMA",
        "Name[hu]": "LZMA bővítmény",
        "Name[ia]": "Plugin de LZMA",
        "Name[it]": "Estensione LZMA",
        "Name[ko]": "LZMA 플러그인",
        "Name[nl]": "LZMA-plug-in",
        "Name[nn]": "LZMA-tillegg",
        "Name[pl]": "Wtyczka LZMA",
        "Name[pt]": "'Plugin' do LZMA",
        "Name[pt_BR]": "Plugin LZMA",
        "Name[ro]": "Extensie LZMA",
        "Name[ru]": "Модуль LZMA",
        "Name[sk]": "Plugin LZMA",
        "Name[sl]": "Vstavek LZMA",
        "Name[sr@ijekavian]": "Прикључак за ЛЗМА",
        "Name[sr@ijekavianlatin]": "Priključak za LZMA",
        "Name[sr@latin]": "Priključak za LZMA",
        "Name[sr]": "Прикључак за ЛЗМА",
        "Name[sv]": "LZMA-insticksprogram",
        "Name[tr]": "LZMA eklentisi",
        "Name[uk]": "Додаток LZMA",
        "Name[x-test]": "xxLZMA pluginxx",
        "Name[zh_CN]": "LZMA 插件",
        "Name[zh_TW]": "LZMA 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}

==> ark_20.12.2.orig.tar.xz: ark-20.12.2/plugins/libsinglefileplugin/kerfuffle_libxz.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the lzma algorithm",
        "Description[az]": "lzma alqoritmi ilə sıxlaşdırılan tək faylları açmaq və çıxartmaq",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «lzma»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «lzma»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem lzma",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med lzma-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem LZMA-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο Izma",
        "Description[en_GB]": "Open and extract single files compressed with the lzma algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo lzma",
        "Description[et]": "Lzma algoritmiga pakitud failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi lzma algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[fi]": "Avaa ja pura LZMA-algoritmilla pakattuja yksittäistiedostoja",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme « lzma »",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo lzma.",
        "Description[hu]": "Az lzma algoritmussal tömörített fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo lzma",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo lzma",
        "Description[ko]": "lzma 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het lzma-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med lzma-algoritmen",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem lzma",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo LZMA",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo LZMA",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul lzma",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму lzma",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom lzma",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom lzma",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом ЛЗМА",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom LZMA",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom LZMA",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом ЛЗМА",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med lzma-algoritmen",
        "Description[tr]": "Lzma algoritması ile sıkıştırılmış tek dosyaları açma ve çıkarma",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму lzma",
        "Description[x-test]": "xxOpen and extract single files compressed with the lzma algorithmxx",
        "Description[zh_CN]": "打开和解压 lzma 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 lzma 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libxz",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "LZMA plugin",
        "Name[az]": "LZMA qoşması",
        "Name[ca@valencia]": "Connector del LZMA",
        "Name[ca]": "Connector del LZMA",
        "Name[cs]": "Modul pro LZMA",
        "Name[da]": "LZMA-plugin",
        "Name[de]": "LZMA-Modul",
        "Name[el]": "Πρόσθετο LZMA",
        "Name[en_GB]": "LZMA plugin",
        "Name[es]": "Complemento LZMA",
        "Name[et]": "LZMA plugin",
        "Name[eu]": "LZMA plugina",
        "Name[fi]": "LZMA-liitännäinen",
        "Name[fr]": "Module externe « LZMA »",
        "Name[gl]": "Complemento de LZMA",
        "Name[hu]": "LZMA bővítmény",
        "Name[ia]": "Plugin de LZMA",
        "Name[it]": "Estensione LZMA",
        "Name[ko]": "LZMA 플러그인",
        "Name[nl]": "LZMA-plug-in",
        "Name[nn]": "LZMA-tillegg",
        "Name[pl]": "Wtyczka LZMA",
        "Name[pt]": "'Plugin' do LZMA",
        "Name[pt_BR]": "Plugin LZMA",
        "Name[ro]": "Extensie LZMA",
        "Name[ru]": "Модуль LZMA",
        "Name[sk]": "Plugin LZMA",
        "Name[sl]": "Vstavek LZMA",
        "Name[sr@ijekavian]": "Прикључак за ЛЗМА",
        "Name[sr@ijekavianlatin]": "Priključak za LZMA",
        "Name[sr@latin]": "Priključak za LZMA",
        "Name[sr]": "Прикључак за ЛЗМА",
        "Name[sv]": "LZMA-insticksprogram",
        "Name[tr]": "LZMA eklentisi",
        "Name[uk]": "Додаток LZMA",
        "Name[x-test]": "xxLZMA pluginxx",
        "Name[zh_CN]": "LZMA 插件",
        "Name[zh_TW]": "LZMA 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}
